@@ -1,8 +1,10 @@
 from wcs.services.mgrbase import MgrBase
-from wcs.commons.config import MGR_URL
-from wcs.commons.config import logging_folder
+from wcs.commons.config import Config
 from wcs.commons.http import _get
-from wcs.commons.logme import debug, warning, error 
+from wcs.commons.logme import debug,error 
+from wcs.commons.util import https_check
+
+MGR = Config.mgr_url
 
 class WsLive(MgrBase):
 
@@ -27,10 +29,8 @@ class WsLive(MgrBase):
             query['start'] = start
         if limit is not None:
             query['limit'] = limit
-        url = self._make_list_url(query)
+        url = https_check(self._make_list_url(query))
         if query is not None:
             debug('List params is %s' % query)
         debug('List bucket %s' % bucket)
-        code, text = _get(url=url, data=query, headers=super(WsLive, self)._gernerate_headers(url)) 
-        debug('The return code : %d, text : %s' % (code, text))
-        return code, text 
+        return _get(url=url, headers=super(WsLive, self)._gernerate_headers(url)) 
